@@ -1,6 +1,6 @@
 package Silki::Role::Controller::User;
 BEGIN {
-  $Silki::Role::Controller::User::VERSION = '0.21';
+  $Silki::Role::Controller::User::VERSION = '0.23';
 }
 
 use strict;
@@ -219,7 +219,10 @@ sub _user_update_error {
 
     my $uri
         = $c->request()->params()->{confirmation_key}
-        ? $c->stash()->{user}->confirmation_uri( view => 'preferences_form' )
+        ? $c->stash()->{user}->confirmation_uri(
+        view => 'preferences_form',
+        host => $c->domain()->web_hostname(),
+        )
         : $self->_make_user_uri(
         $c,
         $c->stash()->{user},
@@ -258,7 +261,7 @@ Silki::Role::Controller::User - Provides user-related methods and actions
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 AUTHOR
 
