@@ -1,6 +1,6 @@
 package Silki::Schema::User;
 BEGIN {
-  $Silki::Schema::User::VERSION = '0.21';
+  $Silki::Schema::User::VERSION = '0.23';
 }
 
 use strict;
@@ -992,19 +992,19 @@ sub forgot_password {
 
     $self->_send_email(
         @_,
-        sender => $self,
-        subject =>
-            loc( 'Password reset for %1', $self->domain()->web_hostname() ),
+        sender   => $self,
+        subject  => loc('Password reset for Silki'),
         template => 'forgot-password',
     );
 }
 
 sub _send_email {
     my $self = shift;
-    my ( $wiki, $sender, $message, $subject, $template ) = validated_list(
+    my ( $wiki, $sender, $domain, $message, $subject, $template ) = validated_list(
         \@_,
         wiki     => { isa => 'Silki::Schema::Wiki', optional => 1 },
         sender   => { isa => 'Silki::Schema::User' },
+        domain   => { isa => 'Silki::Schema::Domain', default => Silki::Schema::Domain->DefaultDomain() },
         message  => { isa => Str,                   optional => 1 },
         subject  => { isa => Str,                   optional => 1 },
         template => { isa => Str },
@@ -1043,6 +1043,7 @@ sub _send_email {
         template_params => {
             user    => $self,
             wiki    => $wiki,
+            domain  => $domain,
             sender  => $sender,
             message => $message,
         },
@@ -1169,7 +1170,7 @@ Silki::Schema::User - Represents a user
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 AUTHOR
 
